from strongr.clouddomain.handler.abstract.cloud import AbstractRequestJidStatusHandler

class RequestJidStatusHandler(AbstractRequestJidStatusHandler):
    def __call__(self, query):
        pass # not really required yet
